﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Windows;
using System.Windows.Interactivity;
using Infragistics.Controls.Menus;

namespace WpfApplication1.Util
{
    public class NodeSelectionBehavior : Behavior<XamDataTree>
    {
        public string IsSelectedMemberPath
        {
            get { return (string)GetValue(IsSelectedMemberPathProperty); }
            set { SetValue(IsSelectedMemberPathProperty, value); }
        }

        // Using a DependencyProperty as the backing store for IsSelectedMemberPath.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty IsSelectedMemberPathProperty =
            DependencyProperty.Register("IsSelectedMemberPath", typeof(string), typeof(NodeSelectionBehavior), new PropertyMetadata(string.Empty));

        protected override void OnAttached()
        {
            base.OnAttached();

            AssociatedObject.SelectedNodesCollectionChanged += AssociatedObject_SelectedNodesCollectionChanged;
        }

        void AssociatedObject_SelectedNodesCollectionChanged(object sender, NodeSelectionEventArgs e)
        {
            // deselect the old ones
            foreach (var node in e.OriginalSelectedNodes)
            {
                if (node.Data != null)
                {
                    PropertyInfo pInfo = node.Data.GetType().GetProperty(IsSelectedMemberPath);
                    pInfo.SetValue(node.Data, false, null);
                }
            }

            // select the new nodes.
            foreach (var node in e.CurrentSelectedNodes)
            {
                if (node.Data != null)
                {
                    PropertyInfo pInfo = node.Data.GetType().GetProperty(IsSelectedMemberPath);
                    pInfo.SetValue(node.Data, true, null);
                }
            }
        }
    }
}
